pub fn encode(doc: &SceneDoc, source_hash: u64, source_len: u64) -> Vec<u8> ⓘExpand description
Encode a scene document as a cache payload stamped with the live
CACHE_VERSION and FORMAT_VERSION.
pub fn encode(doc: &SceneDoc, source_hash: u64, source_len: u64) -> Vec<u8> ⓘEncode a scene document as a cache payload stamped with the live
CACHE_VERSION and FORMAT_VERSION.